<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Events;
use Carbon\Carbon;
use Illuminate\Http\Request;

class EventController extends Controller
{
    public function latest_event(){
        $events = Events::where('status', '1')->orderBy('id', 'Desc')->take(15)->get();
       
        $response = collect($events)->map(function ($eventItem) {
          
            return [
                'id' => $eventItem->id,
                'image' => $eventItem->image ? asset('uploads/events/' . $eventItem->image) : null,
                'event_name' => $eventItem->title,
                'from_date' =>Carbon::parse($eventItem->start_date)->format('j M Y'),
                'to_date' =>$eventItem->end_date ? Carbon::parse($eventItem->end_date)->format('j M Y'):null,
                'from_time' => Carbon::parse($eventItem->start_time)->format('g:i A'),
                'to_time' => Carbon::parse($eventItem->end_time)->format('g:i A'),
                'venue' =>$eventItem->place,

            ];
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }

    public function all_events(){
        $events = Events::where('status', '1')->orderBy('id', 'Desc')->get();
       
        $response = collect($events)->map(function ($eventItem) {
          
            return [
                'id' => $eventItem->id,
                'image' => $eventItem->image ? asset('uploads/events/' . $eventItem->image) : null,
                'event_name' => $eventItem->title,
                'from_date' =>Carbon::parse($eventItem->start_date)->format('j M Y'),
                'to_date' =>$eventItem->end_date ? Carbon::parse($eventItem->end_date)->format('j M Y'):null,
                'from_time' => Carbon::parse($eventItem->start_time)->format('g:i A'),
                'to_time' => Carbon::parse($eventItem->end_time)->format('g:i A'),
                'venue' =>$eventItem->place,

            ];
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }

    public function events(string $id){
        $events = Events::where('id', $id)->where('status', '1')->get();
        if ($events->isEmpty()) {
            return response()->json([
                'status' => false,
                'error' => 'No events found',
            ], 422);
        }
        
        $response = collect($events)->map(function ($eventItem) {
          $attachments = $eventItem->eventattachments;
            return [
                'id' => $eventItem->id,
                'image' => $eventItem->image ? asset('uploads/events/' . $eventItem->image) : null,
                'event_name' => $eventItem->title,
                'from_date' =>Carbon::parse($eventItem->start_date)->format('j M Y'),
                'to_date' =>$eventItem->end_date ? Carbon::parse($eventItem->end_date)->format('j M Y'):null,
                'from_time' => Carbon::parse($eventItem->start_time)->format('g:i A'),
                'to_time' => Carbon::parse($eventItem->end_time)->format('g:i A'),
                'venue' =>$eventItem->place,
                'address' => $eventItem->address,
                'short_desc' => $eventItem->short_description,
                'long_desc' => $eventItem->detailed_description,
                'event_link' => $eventItem->event_link ? $eventItem->event_link :null,
                'event_notification' =>$eventItem->event_notification,
                'attachments' => collect($attachments)->map(function ($attachItem) {
                    return asset('uploads/events/Attachments' . $attachItem->attach);
                })
            ];                                                       
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }


public function live_events(){
    // $date = Carbon::now()->format('Y-m-d');
    $date = '2023-11-01';
    $events = Events::where('status', '1')->where('start_date',$date)->orderBy('id', 'Desc')->get();
       
    $response = collect($events)->map(function ($eventItem) {
      
        return [
            'id' => $eventItem->id,
            'image' => $eventItem->image ? asset('uploads/events/' . $eventItem->image) : null,
            'event_name' => $eventItem->title,
            'from_date' =>Carbon::parse($eventItem->start_date)->format('j M Y'),
            'to_date' =>$eventItem->end_date ? Carbon::parse($eventItem->end_date)->format('j M Y'):null,
            'from_time' => Carbon::parse($eventItem->start_time)->format('g:i A'),
            'to_time' => Carbon::parse($eventItem->end_time)->format('g:i A'),
            'venue' =>$eventItem->place,

        ];
    });
    if(!empty($response)){
        return response()->json(
            array(
                'status' => True,
                'data' => $response
            ),
            200
        );
    }
  else{
    return response()->json(
        array(
            'status' => False,
            'error' => "Something went wrong"
        ),
        422
    );
  }
}
}
