<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\News;
use Carbon\Carbon;
use Illuminate\Http\Request;

class NewsController extends Controller
{
    public function latest_news(){
        $news = News::where('status', '1')->orderBy('id', 'Desc')->take(15)->get();
        $news_count = count($news);
        if ($news->isEmpty()) {
            return response()->json([
                'status' => false,
                'error' => 'No news found',
            ], 422);
        }
        $response = collect($news)->map(function ($newsItem) {
            $image = $newsItem->newsgallery->where('is_featured_image', 1)->first();
        
            return [
                'id' => $newsItem->id,
                'image' => $image ? asset('uploads/news/' . $image->image) : null,
                'heading' => $newsItem->title,
                'published_date' =>Carbon::parse($newsItem->published_date)->format('d M Y l'),
                'published_time' => Carbon::parse($newsItem->published_time)->format('g:i A')
            ];
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'total_news' =>$news_count,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }
    public function all_news(){
        $news = News::where('status', '1')->orderBy('id', 'Desc')->get();
        $news_count = count($news);
        if ($news->isEmpty()) {
            return response()->json([
                'status' => false,
                'error' => 'No news found',
            ], 422);
        }
        $response = collect($news)->map(function ($newsItem) {
            $image = $newsItem->newsgallery->where('is_featured_image', 1)->first();
        
            return [
                'id' => $newsItem->id,
                'image' => $image ? asset('uploads/news/' . $image->image) : null,
                'heading' => $newsItem->title,
                'published_date' =>Carbon::parse($newsItem->published_date)->format('d M Y l'),
                'published_time' => Carbon::parse($newsItem->published_time)->format('g:i A')
            ];
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'total_news' =>$news_count,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }

    public function news(string $id){
        $news = News::where('id', $id)->where('status', '1')->get();;
       
        if ( $news == null || $news->isEmpty() ) {
            return response()->json([
                'status' => false,
                'error' => 'No news found with the id',
            ], 422);
        }
        $response = collect($news)->map(function ($newsItem) {
            $image = $newsItem->newsgallery->where('is_featured_image', 1)->first();
            $gallery = $newsItem->newsgallery;
             
            return [
                'id' => $newsItem->id,
                'featured_image' => $image ? asset('uploads/news/' . $image->image) : null,
                'heading' => $newsItem->title,
                'published_date' =>Carbon::parse($newsItem->published_date)->format('d M Y l'),
                'published_time' => Carbon::parse($newsItem->published_time)->format('g:i A'),
                'detailed_news' => $newsItem->detailed_news,
                'images' => collect($gallery)->filter(function ($galleryItem) {
                    return $galleryItem->is_featured_image !== 1;
                })->map(function ($galleryItem) {
                    return asset('uploads/news/' . $galleryItem->image);
                })
            ];
        });
        if(!empty($response)){
            return response()->json(
                array(
                    'status' => True,
                    'data' => $response
                ),
                200
            );
        }
      else{
        return response()->json(
            array(
                'status' => False,
                'error' => "Something went wrong"
            ),
            422
        );
      }
    }
}
