<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Yajra\DataTables\DataTables;
use App\Models\Banner;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Storage;



class BannerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.banner.list');
        
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.banner.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
        $banner = new Banner();
        if ($request->file('image')) {
            $image = $request->file('image');
            $filename = time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/banner');
            $image->move($path, $filename);
            $banner->image = $filename;
        }
        
        $banner->status = 1;
        $banner->save();
        return redirect()->route('admin.banner');

    }


    public function getBanner(Request $request)
    {
        if ($request->ajax()) {
            $data = Banner::orderBy('id', 'DESC')->get();
            return Datatables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-banner', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
               
                ->addColumn('banner', function ($data) {
                    return  '<img src="' . asset('uploads/banner/' . $data->image) . '" width="100" height="100">';
                })
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
    }


    public function changeStatus (Request $request){

    }
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data=Banner::find($id);
        return view('admin.pages.banner.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $data = Banner::find($id);
    
        if ($data) {
            if ($request->hasFile('image')) {
                if ((file_exists(public_path('uploads/banner/' . $data->image))) && ($data->image != NULL)) {
                    unlink("uploads/banner/" . $data->image);
                }
    
                $image = $request->file('image');
                $filename = time() . '.' . $image->getClientOriginalExtension();
                $path = public_path('uploads/banner');
                $image->move($path, $filename);
    
                $data->image = $filename;
            }
    
            if ($data->save()) {
                return redirect()->route('admin.banner')->with('success', 'Banner Updated Successfully');
            }
        }
    
        return back()->with('error', 'Something Went Wrong');
    }
    public function changeBannerStatus(Request $request)
    {

        $res = Banner::where('id', $request->id)
            ->update(['status' => $request->status]);

        return $res;
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $id = $request->id;
        $data = Banner::find($id);
        if ((file_exists(public_path('uploads/banner/' . $data->image))) && ($data->image != NULL)) {
            unlink("uploads/banner/" . $data->image);
        }
        $res = $data->delete();
        if($res){
            return redirect()->route('admin.banner');
        }

    }
}
