<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ChurchGallery;
use App\Models\ChurchLocator;
use App\Models\News;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class ChruchLocatorController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.church_locator.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.church_locator.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        $validator =Validator::make($request->all(), [
            'church_name' => 'required',
            'phone' => 'required|unique:church_locators,phone',
            'address' => 'required',
            'about_church' => 'required',
            'locator_url' => 'nullable|url',
            'featured_image' =>'required|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            'gallery_image'=>'nullable|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
     
     

      
        $churchid = ChurchLocator::insertGetId(
            [
                'church_name' => $request->church_name,
                'phone' => $request->phone,
                'address' => $request->address,
                'about_church' => $request->about_church,
                'locator_url' => $request->locator_url,
                
            ]
        );
         if($churchid){
             if($request->hasFile('featured_image')){
                $image = $request->file('featured_image');
                $filename = 'church-'.time() . '.' . $image->getClientOriginalExtension();
                 $path = public_path('uploads/churches');
                $image->move($path, $filename);

                $churchgallery = new ChurchGallery();
                $churchgallery->image = $filename;
                $churchgallery->is_featured_image = 1;
                $churchgallery->church_id = $churchid;
                $churchgallery->save();
         }
         if($request->hasFile('gallery_images')){
            $images = $request->file('gallery_images');
            foreach ($images as $galleryimage) {
               
                // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                $filename = 'church-'.time() . '.' . $galleryimage->getClientOriginalName();
                $path = public_path('uploads/churches');
                $galleryimage->move($path, $filename);
        
                // You can now save the $filename to your database or perform any other operations you need.
               // You should create an instance of the NewsGallery model or use your own model name
               $churchgallery = new ChurchGallery();
               $churchgallery->image = $filename;
               $churchgallery->is_featured_image = 0;
               $churchgallery->church_id = $churchid;
               $churchgallery->save();
         }

        }
        return redirect()->back()->with('success','Church Locator created successfully'); 
    }
    else{
        return redirect()->back()->with('error','Something went wrong');
    }
    
       
    }
    public function changeChurchLocatorStatus(Request $request){
        $res = ChurchLocator::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }

    
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }
    public function updateChurchImage(string $id){
        $data= ChurchGallery::find($id);
        $church = ChurchLocator::find($data->church_id);
        $image  = $church->churchgallery->where('is_featured_image', 1)->first();
        if($image != null){
            $image->is_featured_image = 0;
            $image->save();
        }
    
        if ($data) {
            $data->is_featured_image = 1;
            $data->save();
            return redirect()->back()->with('success','Featured image updated successfully');
        }
    }



    public function editchurchgallery (Request $request,string $id){
        $data= ChurchGallery::find($id);
        return view('admin.pages.church_locator.editchurchgallery',compact('data'));
        
    }
    public function destroychurchgallery (string $id){
        $data= ChurchGallery::find($id);
        if($data){
            if((file_exists(public_path('uploads/churches/' . $data->image))) && ($data->image != NULL)) {
                unlink("uploads/churches/" . $data->image);
            }
            $data->delete();
            return redirect()->back()->with('success','Church gallery image deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong');
        }
    }
    public function updatechurchgallery(Request $request,string $id){
        $data= ChurchGallery::find($id);
        if ($data) {
            if ($request->hasFile('image')) {
                $Churchimage = $request->file('image');
                if ((file_exists(public_path('uploads/churches/' . $data->image))) && ($data->image != NULL)) {
                    unlink("uploads/churches/" . $data->image);
                }
                $filename = 'church-' . time() . '.' . $Churchimage->getClientOriginalExtension();
                $path = public_path('uploads/churches');
                $Churchimage->move($path, $filename);
                $data->image = $filename;
                $id = $data->church_id;
                $data->save();
                
                
                return redirect()->route('admin.edit-church-locator',['id' => $id])->with('success','Church gallery image updated successfully');

                
            }
    }


}

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = ChurchLocator::find($id);
        return view('admin.pages.church_locator.edit',compact('data'));
    }

    public function get_church_locator(Request $request){
        if ($request->ajax()) {
            $data = ChurchLocator::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-church-locator', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
               
                ->addColumn('featured_image', function ($data) {
                     $image = $data->churchgallery->where('is_featured_image', 1)->first();
                    if($image != null){
                        return  '<img src="' . asset('uploads/churches/' . $image->image) . '" width="100" height="100">';
                    }
                    return $image;
                    
                })
            
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
                
        
     
    }
    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator =Validator::make($request->all(), [
            'church_name' => 'required',
            'phone' => 'required|unique:church_locators,phone',
            'address' => 'required',
            'about_church' => 'required',
            'locator_url' => 'nullable|url',
             'gallery_image'=>'nullable|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        $church = ChurchLocator::find($id);
        if($church){
            $res = $church->update($input);
        }

        if($request->hasFile('gallery_images')){
            $images = $request->file('gallery_images');
            foreach ($images as $galleryimage) {
               
                // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                $filename = 'church-'.time() . '.' . $galleryimage->getClientOriginalName();
                $path = public_path('uploads/churches');
                $galleryimage->move($path, $filename);
        
                // You can now save the $filename to your database or perform any other operations you need.
               // You should create an instance of the NewsGallery model or use your own model name
               $churchgallery = new ChurchGallery();
               $churchgallery->image = $filename;
               $churchgallery->is_featured_image = 0;
               $churchgallery->church_id = $id;
               $churchgallery->save();
         }

        }
        if($res){
            return redirect()->back()->with('success','church locator updated successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $church = ChurchLocator::find($request->id);
        if($church){
            $churchgallery = $church->churchgallery;
           
            foreach($churchgallery as $data){
                if ($data->image !== null && file_exists(public_path('uploads/churches/' . $data->image))) {
                    // Delete the image file
                    unlink(public_path('uploads/churches/' . $data->image));
                    $data->delete();
                }
                
                // Delete the record from the 'newsgallery' table
               
                
              
            }
            $res = $church->delete();
            if($res){
                return redirect()->back()->with('success','church locator deleted successfully');
               }
               else{
                return redirect()->back()->with('error','Something went wrong');
               }
           
        }
        else{
            return redirect()->back()->with('error','church locator Record not found');
        }
       
       
      
      
    }
    
}
