<?php

namespace App\Http\Controllers\Admin\Diocese;

use App\Http\Controllers\Controller;
use App\Models\BookStore;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\DataTables;


class BookStoreController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.diocese.bookstore.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.diocese.bookstore.add');

    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required|unique:book_stores,book_name',
            'about_book' =>'required',
            'book_cover' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'author' =>'required',
            'actual_price' => 'required',
            'seller_price'=>'nullable',
            'discount' => 'nullable',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        if($request->hasFile('book_cover')){
            $image = $request->file('book_cover');
            $filename = 'book-'.time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/books');
            $image->move($path, $filename);
         
       
            
    }
        $book = new BookStore();
        $book->book_name = $request->title;
        $book->about_book = $request->about_book;
        $book->author_name = $request->author;
        $book->actual_price = $request->actual_price ?? null;
        $book->seller_price = $request->seller_price ?? null;
        $book->discount = $request->discount ?? null;
        $book->image = $filename;
      
       $res= $book->save();
 if($res){
    return redirect()->back()->with('success', 'Book Store Added Successfully');
 }
 else {
    if(file_exists(public_path('uploads/books/'.$filename))){
        unlink(public_path('uploads/books/'.$filename));
    }
    return redirect()->back()->with('error', 'Something went wrong');
 }
    }

    /**
     * Display the specified resource.
     */
    public function show(Request $request)
    {
        if ($request->ajax()) {
            $data = BookStore::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.bookstore.edit', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
               
                ->addColumn('book_cover', function ($data) {
                     $image = $data->image;
                    if($image != null){
                        return  '<img src="' . asset('uploads/books/' . $image) . '" width="100" height="100">';
                    }
                    return $image;
                    
                })
            
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
            }
    }

    /**
     * Show the form for editing the specified resource.
     */


     public function changeBookStoreStatus(Request $request){
        $res = BookStore::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
     }
    public function edit(string $id)
    {
        $data = BookStore::find($id);
        return view('admin.pages.diocese.bookstore.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $book = BookStore::find($id);
        $validator = Validator::make($request->all(), [
            'title' => 'required|unique:book_stores,book_name',
            'about_book' =>'required',
            'book_cover' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'author' =>'required',
            'actual_price' => 'required',
            'seller_price'=>'nullable',
            'discount' => 'nullable',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        if($request->hasFile('book_cover')){
            
            $image = $request->file('book_cover');
            $filename = 'book-'.time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/books');
            $image->move($path, $filename);
            if(file_exists(public_path('uploads/books/'.$book->image))){
                unlink(public_path('uploads/books/'.$book->image));
            }
            $book->image = $filename;
    }
       
        $book->book_name = $request->title;
        $book->about_book = $request->about_book;
        $book->author_name = $request->author;
        $book->actual_price = $request->actual_price ?? null;
        $book->seller_price = $request->seller_price ?? null;
        $book->discount = $request->discount ?? null;
      
       $res= $book->save();
       if($res){
        return redirect()->back()->with('success', 'Book Store updated Successfully');
       }
       else{
        if(file_exists(public_path('uploads/books/'.$filename))){
            unlink(public_path('uploads/books/'.$filename));
        }
           return redirect()->back()->with('error', 'Something went wrong');
       }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $id = $request->id;
        $data = BookStore::find($id);
       
        if ((file_exists(public_path('uploads/books/' . $data->image))) && ($data->image != NULL)) {
            unlink("uploads/books/" . $data->image);
            $res = $data->delete();
        }
       
        if($res){
            return redirect()->back()->with('sucess', 'Book deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong while deleting event');
        }
    }
}
