<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\EventAttach;
use App\Models\Events;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class EventController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
       return view('admin.pages.events.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.events.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        $rules = [
            'title' => 'required',
            'start_date' => 'required|date',
             'start_time' => 'required|date_format:H:i',
             'end_date' => [
                'nullable',
                'date',
                function ($attribute, $value, $fail) use ($request) {
                    $start_date = $request->input('start_date');
                    if ($value !== null && strtotime($value) <= strtotime($start_date)) {
                        $fail($attribute . ' must be a date after the start date.');
                    }
                },
            ],
            'end_time' => [
                'nullable',
                'date_format:H:i',
                function ($attribute, $value, $fail) use ($request) {
                    $start_time = $request->input('start_time');
                    $end_date = $request->input('end_date');
                    if ($value !== null && $end_date === null && strtotime($value) <= strtotime($start_time)) {
                        $fail($attribute . ' must be a time after the start time when end date is not provided.');
                    }
                },
            ],
            'event_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'event_detail' => 'required',
            'event_venue' => 'required',
            'address' =>     'required',
            'event_short' => 'required',
            'event_detail' => 'required',
            'event_link' => 'nullable|url',
            'location_url' => 'nullable|url',
           

        ];
        $validate = Validator::make($request->all(), $rules);
         
       
        if ($validate->fails()) {
            return redirect()->back()->withErrors($validate)->withInput();
        }
        else{
            $input  = $request->all();
            $event = new Events();
            if($request->hasFile('event_image')){
                $image = $request->file('event_image');
                $filename = 'event-'.time() . '.' . $image->getClientOriginalExtension();
                $path = public_path('uploads/events');
                $image->move($path, $filename);
                $input['image'] = $filename;
                
        }
        $input['place'] = $request->event_venue;
        $input['short_description'] = $request->event_short;
        $input['detailed_description'] = $request->event_detail;
        $input['event_link'] = $request->eventlink ?? null;
        $input['event_notification'] = $request->hiddenToggleEvent ?? 0;
        $input['location_url'] = $request->location_url ?? null;
        $eventsave = $event->create($input);
        $eventId = $eventsave->id;
        if($eventId){
            if($request->hasFile('event_attach')){
                $image = $request->file('event_attach');
                foreach ($image as $eventattach) {
                $filename = 'events-'.time().$eventattach->getClientOriginalExtension();
                $path = public_path('uploads/events/Attachments');
                $eventattach->move($path, $filename);
               
                $eventattach = new EventAttach();
                $eventattach->attach = $filename;
               
                $eventattach->events_id = $eventId;
                $eventattach->save();
                }
            }
            return redirect()->back()->with('success', 'Event created successfully');
        }
               
       else{
            return redirect()->back()->with('error', 'Event not created');
       }
        }
             
    
}

public function getevents(Request $request){
    if ($request->ajax()) {
        $data = Events::orderBy('id', 'DESC')->get();
        return DataTables::of($data)
           ->addIndexColumn()
            ->addColumn('action', function ($data) {
                $actionBtn = ' 
                <a href="' . route('admin.edit-event', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                
                <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                return $actionBtn;
            })
            ->addColumn('start_date', function ($data) {
                $startDate = Carbon::parse($data->start_date);
                $startDay = $startDate->format('l');
                if ($data->end_date != null) {
                  
                    $endDate = Carbon::parse($data->end_date);
                    
                    $dateDiff = $endDate->diffInDays($startDate);
                    
                     // Get the day of the week for the start date
                    $endDay = $endDate->format('l');     // Get the day of the week for the end date
                
                    return $startDate->format('d-m-Y') . " $startDay - <br/> " . $endDate->format('d-m-Y') . " $endDay <br/> ({$dateDiff} days)";
                }
                else{
                    return "{$data->start_date} $startDay";
                }
            })
           
            ->addColumn('event_image', function ($data) {
               $image = $data->image;
                if($image != null){
                    return  '<img src="' . asset('uploads/events/' . $image) . '" width="100" height="100">';
                }
               
                
            })
            
            ->addColumn('status', function ($data) {
                if ($data->status == 1) {
                    $status = 'Active';
                    $class = "success";
                    $val = 0;
                } else {
                    $status = 'Inactive';
                    $class = "danger";
                    $val = 1;
                }
                return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
            })
            ->escapeColumns([])

            ->make(true);
    }

}



public function deleteEventAttachment(string $id){
    // $id = $request->id;
    $eventattach = EventAttach::find($id);
    if((file_exists(public_path('uploads/events/Attachments/' . $eventattach->attach))) && ( $eventattach->attach != NULL)) {
        unlink("uploads/events/Attachments/" .  $eventattach->attach);
        $res =  $eventattach->delete();
    
    }
 
  
    if ($res) {
        return redirect()->back()->with('sucess', 'Attachment deleted successfully.');
        // return response()->json(['success' => 'Attachment deleted successfully.']);
    } else {
        return redirect()->back()->with('error', 'Something went wrong.');
        // return response()->json(['error' => 'Something went wrong.']);
    }
    
}

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data= Events::find($id);
        return view('admin.pages.events.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $rules = [
            'title' => 'required',
            'start_date' => 'required|date',
            'event_detail' => 'required',
            'event_venue' => 'required',
            'address' => 'required',
            'event_short' => 'required',
            'event_detail' => 'required',
            'event_link' => 'nullable|url',
            'location_url' => 'nullable|url',
            'event_attach' => 'nullable'
            
        ];
    
        $validate = Validator::make($request->all(), $rules);
    
        if ($validate->fails()) {
            return redirect()->back()->withErrors($validate)->withInput();
        }
    
        $event = Events::find($id);
    
        if (!$event) {
            return redirect()->back()->with('error', 'Event not found');
        }
        $input  = $request->all();
      
        if ($request->hasFile('event_image')) {
            $image = $request->file('event_image');
            $filename = 'events-'.time() .'.'.$image->getClientOriginalExtension();
            $path = public_path('uploads/events');
            $image->move($path, $filename);
    
            if (file_exists(public_path('uploads/events/' . $event->image)) && $event->image !== null) {
                unlink("uploads/events/" . $event->image);
            }
    
            $input['image'] = $filename;
        }
        if($request->hasFile('event_attach')){
            $image = $request->file('event_attach');
            foreach ($image as $eventattach) {
            $filename = 'events-'.time() . '.'.$eventattach->getClientOriginalExtension();
            $path = public_path('uploads/events/Attachments');
            $eventattach->move($path, $filename);
           
            $eventattach = new EventAttach();
            $eventattach->attach = $filename;
           
            $eventattach->events_id = $id;
            $eventattach->save();
            }
        }


    
        $input['place'] = $request->event_venue;
        $input['short_description'] = $request->event_short;
        $input['detailed_description'] = $request->event_detail;
        $input['event_link'] = $request->eventlink ?? null;
    $input['location_url'] = $request->location_url ?? null;
    $input['event_notification'] = $request->hiddenToggleEvent ?? 0;
        $res = $event->update($input);
    
        if ($res) {
            return redirect()->back()->with('success', 'Event updated successfully');
        } else {
            return redirect()->back()->with('error', 'Something went wrong while updating event');
        }
    }



    public function  editEventAttachment(string $id){
        $data= EventAttach::find($id);
        return view('admin.pages.events.editattachment',compact('data'));
    }

    public function updateEventAttachment(Request $request){
        $data = EventAttach::find($request->id);
    
        if (!$data) {
            return redirect()->route('admin.edit-event',['id' => $data->events_id])->with('error','Event attachment not found');
        }
    
        if ($request->hasFile('event_attach')) {
            $oldAttachmentPath = public_path('uploads/events/Attachments/' . $data->attach);
    
            if(file_exists($oldAttachmentPath)) {
                unlink($oldAttachmentPath);
            }
    
            $eventattach = $request->file('event_attach');
            $filename = 'events-' . time() . '.' . $eventattach->getClientOriginalExtension();
            $path = public_path('uploads/events/Attachments');
            $eventattach->move($path, $filename);
    
            $data->update(['attach' => $filename]);
    
            return redirect()->route('admin.edit-event', ['id' => $data->events_id])->with('success', 'Event attachment updated successfully');
        }
    
        return redirect()->route('admin.edit-event', ['id' => $data->events_id])->with('error', 'No file provided for update');
    }

    public function changeEventStatus(Request $request){
        $res = Events::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }
   
    
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $id = $request->id;
        $data = Events::find($id);
        if ((file_exists(public_path('uploads/events/' . $data->image))) && ($data->image != NULL)) {
            unlink("uploads/events/" . $data->image);
        }
        $res = $data->delete();
        if($res){
            return redirect()->back()->with('sucess', 'Event deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong while deleting event');
        }
    }
}
