<?php

namespace App\Http\Controllers\Admin\Metropolitan;

use App\Http\Controllers\Controller;
use App\Models\Kalpana;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class KalpanaController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.metropolitan.kalpana.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
       return view('admin.pages.metropolitan.kalpana.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(),[
          'kalpana_name' => 'required',
           'about_kalpana' => 'required',
           'kalpana_pdf' => 'required|mimes:pdf',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $kalpana = new Kalpana();
        if($request->hasFile('kalpana_pdf')){
            $pdf = $request->file('kalpana_pdf');
            $filename = 'kalpana_pdf-'.time() . '.' . $pdf->getClientOriginalExtension();
            $path = public_path('uploads/kalpanapdf');
            $pdf->move($path, $filename);
            $kalpana->kalpana_pdf = $filename;
            
    }
    $kalpana->kalpana_description = $request->about_kalpana;
    $kalpana->kalpana_name = $request->kalpana_name;
    $res = $kalpana->save();
    if($res){
        return redirect()->back()->with('success', 'Kalapna created successfully');
    }
   else{
    if(file_exists(public_path('uploads/kalpanapdf/'.$filename))){
        unlink("uploads/kalpanapdf/" . $filename);
    }
        return redirect()->back()->with('error', 'Kalpana not created');
   }
    }

    /**
     * Display the specified resource.
     */
   

    /**
     * Show the form for editing the specified resource.
     */

     public function getkalpana( Request $request){
        if ($request->ajax()) {
            $data = Kalpana::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-kalpana', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
              
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])
    
                ->make(true);
        }
    
        
    }
    public function changeKalpanaStatus(Request $request)
    {

        $res = Kalpana::where('id', $request->id)
            ->update(['status' => $request->status]);

        return $res;
    }
    public function edit(string $id)
    {
    $data = Kalpana::find($id);
        return view('admin.pages.metropolitan.kalpana.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(),[
            'kalpana_name' => 'required',
             'about_kalpana' => 'required',
             'kalpana_pdf' => 'nullable|mimes:pdf',
          ]);
          if($validator->fails()){
              return redirect()->back()->withErrors($validator)->withInput();
          }
          $kalpana  = Kalpana::find($id);
          if($request->hasFile('kalpana_pdf')){
            if(file_exists(public_path('uploads/kalpanapdf/'.$kalpana->kalpana_pdf))){
                unlink("uploads/kalpanapdf/" . $kalpana->kalpana_pdf);
            }
              $pdf = $request->file('kalpana_pdf');
              $filename = 'kalpana_pdf-'.time() . '.' . $pdf->getClientOriginalExtension();
              $path = public_path('uploads/kalpanapdf');
              $pdf->move($path, $filename);
              $kalpana->kalpana_pdf = $filename;
        }
        $kalpana->kalpana_name = $request->kalpana_name;
        $kalpana->kalpana_description = $request->about_kalpana;
        $res = $kalpana->save();
        if($res){
            return redirect()->back()->with('success', 'Kalapna updated successfully');
        }
        else{
            return redirect()->back()->with('error', 'Kalpana not updated');
        }

    }

    /**
     * Remove the specified resource from storage.
     */
    
        public function destroy(Request $request)

        {
            $id = $request->id;
          $kalpana = Kalpana::find($id);
         
       if(($kalpana->kalpana_pdf !=null) && (file_exists('uploads/kalpanapdf/'.$kalpana->kalpana_pdf))){
        unlink('uploads/kalpanapdf/'.$kalpana->kalpana_pdf);
      
                }
                $res = $kalpana->delete();
                if($res){
                    return redirect()->back()->with('success','Kalpana Record Deleted Successfully');
        
                   }
                   else{
                    return redirect()->back()->with('error','Something Went Wrong unable to Delete Record');
                   }
        
        }   
   
}
