<?php

namespace App\Http\Controllers\Admin\Metropolitan;

use App\Http\Controllers\Controller;
use App\Models\Posts;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class PostController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.metropolitan.posts.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.metropolitan.posts.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
       $validator = Validator::make($request->all(),[
            'title' => 'required',
            'post_des' => 'required',
            'post_image' =>'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',

       ]);
       if($validator->fails()){
           return redirect()->back()->withErrors($validator)->withInput();
       }
       $post = new Posts();
       $post->post_title = $request->title;
       $post->post_description = $request->post_des;
       if($request->hasFile('post_image')){
           $image = $request->file('post_image');
           $filename = 'post_image-'.time() . '.' . $image->getClientOriginalExtension();
           $path = public_path('uploads/posts');
           $image->move($path, $filename);
           $post->image = $filename;
       }
      $res= $post->save();
      if($res){
          return redirect()->back()->with('success', 'Post created successfully');
      }
      else{
          if(file_exists(public_path('uploads/posts/'.$filename))){
              unlink("uploads/posts/" . $filename);
          }
          return redirect()->back()->with('error', 'Something went wrong');
      }
    }

    /**
     * Display the specified resource.
     */
    public function getposts(Request $request)
    {
        if ($request->ajax()) {
            $data = Posts::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-posts', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                ->addColumn('post_image', function ($data) {
                    $image = $data->image;
                    if($image != null){
                        return '<img src="' . asset('uploads/posts/' . $image) . '"  width="100" height="100">';
                     
                    }
                   
                })
                ->addColumn('likes_share', function ($data) {
                    $result = 'Likes:' . ($data->likes ? $data->likes : '0') . ' Shares:' . ($data->shares ? $data->shares : null);
                    return $result;
                })
              
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])
    
                ->make(true);
        }
    }


    public function changePostStatus(Request $request){
        $res = Posts::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }
    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = Posts::find($id);
     return view('admin.pages.metropolitan.posts.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(),[
            'title' => 'required',
            'post_des' => 'required',
            'post_image' =>'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
         if($validator->fails()){
             return redirect()->back()->withErrors($validator)->withInput();
         }
         $post = Posts::find($id);
         $post->post_title = $request->title;
         $post->post_description = $request->post_des;
         if($request->hasFile('post_image')){
            if(file_exists(public_path('uploads/posts/'.$post->image))){
                unlink("uploads/posts/" . $post->image);
            }
             $image = $request->file('post_image');
             $filename = 'post_image-'.time() . '.' . $image->getClientOriginalExtension();
             $path = public_path('uploads/posts');
             $image->move($path, $filename);
             $post->image = $filename;
         }
         $res = $post->update();
         if($res){
             return redirect()->back()->with('success', 'Post updated successfully');
         }
         else{
             return redirect()->back()->with('error', 'Something went wrong');
         }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $id = $request->id;
        $post = Posts::find($id);
        if(file_exists(public_path('uploads/posts/'.$post->image))){
            unlink("uploads/posts/" . $post->image);
        }
        $res = $post->delete();
        if($res){
            return redirect()->back()->with('success', 'Post deleted successfully');
        }
        else{
            return redirect()->back()->with('error', 'Something went wrong');
        }
        
    }
}
