<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\News;
use App\Models\NewsGallery;
use Carbon\Carbon;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class NewsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.news.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.news.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator= Validator::make($request->all(),[
            'title'=>'required',
            'detail_news'=>'required',
            'featured_image'=>'required|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            'news_image'=>'nullable|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            'published_date'=>'nullable|date',
            'published_time' =>'nullable|date_format:H:i',

        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        
        // $news->title = $request->title;
        // $news->category = $request->category;
        // $news->detailed_news = $request->detail_news;
          // Insert the new News record and get the last inserted ID
          if($input['published_date'] == null){
            $input['published_date'] = Carbon::now('Asia/Kolkata');
          }
         
          if($input['published_time'] == null){
            $input['published_time'] = Carbon::now('Asia/Kolkata');
          }
          
          
 
    $newsId = News::insertGetId([
        'title' => $input['title'],
        'category' => $input['category'],
        'detailed_news' => $input['detail_news'],
        'published_date' => $input['published_date'],
        'published_time' => $input['published_time'],
        
       
    ]);
    

    if ($newsId) {
        // Insert the News Images record using the obtained News ID
      

        if($request->hasFile('featured_image')){
            $image = $request->file('featured_image');
            $filename = 'news'.$newsId.time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/news');
            $image->move($path, $filename);
           
            $newsgallery = new NewsGallery();
            $newsgallery->image = $filename;
            $newsgallery->is_featured_image = 1;
            $newsgallery->news_id = $newsId;
            $newsgallery->save();
        }
        if ($request->hasFile('news_images')) {
            $images = $request->file('news_images');
            foreach ($images as $index=>$newsimage) {
                $paddedIndex = str_pad($index + 1, 3, '0', STR_PAD_LEFT);
                // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                $filename = 'news-'.$newsId.$paddedIndex.'.'.$newsimage->getClientOriginalExtension();
                $path = public_path('uploads/news');
                $newsimage->move($path, $filename);
        
                // You can now save the $filename to your database or perform any other operations you need.
                $newsgallery = new NewsGallery(); // You should create an instance of the NewsGallery model or use your own model name
                $newsgallery->image = $filename;
                $newsgallery->is_featured_image = 0;
                $newsgallery->news_id = $newsId;
                $newsgallery->save();
            }
        }
        return redirect()->back()->with('success','News created successfully');
    }
    else{
        return redirect()->back()->with('error','Something went wrong');
    }
        

      
    }

    public function changeNewsStatus(Request $request)
    {

        $res = News::where('id', $request->id)
            ->update(['status' => $request->status]);

        return $res;
    }


    public function getnews(Request $request){
        if ($request->ajax()) {
            $data = News::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-news', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                ->addColumn('published_date', function ($data) {
                    return  Carbon::parse($data->published_date)->format('d-m-Y');
                })
               
                ->addColumn('featured_image', function ($data) {
                     $image = $data->newsgallery->where('is_featured_image', 1)->first();
                    if($image != null){
                        return  '<img src="' . asset('uploads/news/' . $image->image) . '" width="100" height="100">';
                    }
                    return $image;
                    
                })
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = News::find($id);
        return view('admin.pages.news.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $news = News::find($id);
        $validator= Validator::make($request->all(),[
            'title' => 'required',
            'detail_news' => 'required',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
       
        $news->title = $request->title;
        $news->category = $request->category;
        $news->detailed_news = $request->detail_news;
        $news->published_date = $request->published_date;
        $news->published_time = $request->published_time;
        $news->save();
        if ($request->hasFile('news_images')) {
            $images = $request->file('news_images');
            foreach ($images as $newsimage) {
              
                // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                $filename = 'news-'.$id.time().'.'.$newsimage->getClientOriginalName();
                $path = public_path('uploads/news');
                $newsimage->move($path, $filename);
        
                // You can now save the $filename to your database or perform any other operations you need.
                $newsgallery = new NewsGallery(); // You should create an instance of the NewsGallery model or use your own model name
                $newsgallery->image = $filename;
                $newsgallery->is_featured_image = 0;
                $newsgallery->news_id = $id;
                $newsgallery->save();
            }
        }
      
        return redirect()->route('admin.edit-news',['id' => $id])->with('success','News updated successfully');
    }



    public function editnewsgallery (Request $request,string $id){
        $data= NewsGallery::find($id);
        return view('admin.pages.news.editnewsgallery',compact('data'));
        
    }
    public function destroynewsgallery (string $id){
        $data= NewsGallery::find($id);
        if($data){
            if((file_exists(public_path('uploads/news/' . $data->image))) && ($data->image != NULL)) {
                unlink("uploads/news/" . $data->image);
            }
            $data->delete();
            return redirect()->back()->with('success','News gallery image deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong');
        }
    }
    public function updatenewsgallery(Request $request,string $id){
        $data= NewsGallery::find($id);
        if ($data) {
            if ($request->hasFile('image')) {
                $newsimage = $request->file('image');
                if ((file_exists(public_path('uploads/news/' . $data->image))) && ($data->image != NULL)) {
                    unlink("uploads/news/" . $data->image);
                }
                $filename = 'news-' . time() . '.' . $newsimage->getClientOriginalExtension();
                $path = public_path('uploads/news');
                $newsimage->move($path, $filename);
                $data->image = $filename;
                $id = $data->news_id;
                $data->save();
                
                
                return redirect()->route('admin.edit-news',['id' => $id])->with('success','News gallery image updated successfully');

                
            }
    }


}

public function updateFeaturedImage(string $id){
    $data= NewsGallery::find($id);
    $news = News::find($data->news_id);
    $image  = $news->newsgallery->where('is_featured_image', 1)->first();
    if($image != null){
        $image->is_featured_image = 0;
        $image->save();
    }

    if ($data) {
        $data->is_featured_image = 1;
        $data->save();
        return redirect()->back()->with('success','Featured image updated successfully');
    }
}
  
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $news = News::find($request->id);
        if($news){
            $newsgallery = $news->newsgallery;
           
            foreach($newsgallery as $data){
                if ($data->image !== null && file_exists(public_path('uploads/news/' . $data->image))) {
                    // Delete the image file
                    unlink(public_path('uploads/news/' . $data->image));
                    $data->delete();
                }
                
                // Delete the record from the 'newsgallery' table
               
                
              
            }
            $res = $news->delete();
            if($res){
                return redirect()->back()->with('success','News deleted successfully');
               }
               else{
                return redirect()->back()->with('error','Something went wrong');
               }
           
        }
        else{
            return redirect()->back()->with('error','News Record not found');
        }
       
       
      
      
    }
}
