<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\OfficeBearer;
use App\Models\SpiritualWings;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Validation\Rule;

class OfficeBearerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.office_bearer.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $wings = SpiritualWings::all()->where('status', '1');
        return view('admin.pages.office_bearer.add',compact('wings'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'spiritual_wings' => 'required',
            'designation' => [
                'required',
                Rule::unique('office_bearers')
                ->where(function ($query) use ($request) {
                    return $query->where([
                        'spiritual_id' => $request->input('spiritual_wings'),
                        'designation' => $request->input('designation'),
                    ]);
                }),
            ],
            'phone' => 'required',
            'profile_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
                        
            
        ]);
   
$customMessage = 'The combination of spiritual_wings and designation is already present.';
$validator->messages()->add('designation.unique', $customMessage);
        
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        $input['spiritual_id'] = $request->spiritual_wings;
        if($request->hasFile('profile_image')){
            $image = $request->file('profile_image');
            $filename = 'profile-'.time(). '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/office-bearer');
            $image->move($path, $filename);
           $input['image'] = $filename;
          
        }
        
        $officebearer = new OfficeBearer();
        $res = $officebearer->create($input);
        if($res){
            return redirect()->back()->with('success','Office Bearer Added successfully');
        }
        else{
            if(file_exists(public_path('uploads/office-bearer/'.$filename))){
                unlink(public_path('uploads/office-bearer/'.$filename));
            }
            return redirect()->back()->with('error','Something went wrong');
        }
    }


public function getofficebearers( Request $request){
    if ($request->ajax()) {
        $data = OfficeBearer::orderBy('id', 'DESC')->get();
        return DataTables::of($data)
           ->addIndexColumn()
            ->addColumn('action', function ($data) {
                $actionBtn = ' 
                <a href="' . route('admin.edit-office-bearers', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                
                <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                return $actionBtn;
            })
            
           
            ->addColumn('profile_image', function ($data) {
                $image = $data->image;
                if($image != null){
                    return  '<img src="' . asset('uploads/office-bearer/' . $image) . '" width="100" height="100">';
                }
                return $image;
                
            })
        
            
            ->addColumn('spiritual_wings', function ($data) {
              
                return $data->spiritualwing->title;
            })
            ->addColumn('designation', function ($data) {
                if($data->designation == '1'){
                    return 'Vice President ';
                } elseif($data->designation =='2'){
                    return 'Secretary';
                }
                elseif($data->designation =='3'){
                   return 'Join Secretary';                    
                }
                else{
                    return 'Select Designation';
                }
            })
            ->addColumn('status', function ($data) {
                if ($data->status == 1) {
                    $status = 'Active';
                    $class = "success";
                    $val = 0;
                } else {
                    $status = 'Inactive';
                    $class = "danger";
                    $val = 1;
                }
                return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
            })
            ->escapeColumns([])

            ->make(true);
    }

    
}


public function changeOfficeBearerStatus(Request $request)
    {

        $res = OfficeBearer::where('id', $request->id)
            ->update(['status' => $request->status]);

        return $res;
    }
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = OfficeBearer::find($id);
        $wings = SpiritualWings::all()->where('status', '1');
     return view('admin.pages.office_bearer.edit',compact('data','wings'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(),[
            'spiritual_wings' => 'required',
            'designation' => 'required',
            'phone' => 'required',
            'profile_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        $data = OfficeBearer::find($id);
        $input['spiritual_id'] = $request->spiritual_wings;
        if($request->hasFile('profile_image')){

            $image = $request->file('profile_image');
            $filename = 'profile-'.time(). '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/office-bearer');
            $image->move($path, $filename);
            $delimage = $data->image;
            if(file_exists(public_path('uploads/office-bearer/'.$delimage))){
                unlink(public_path('uploads/office-bearer/'.$delimage));
            }
           $input['image'] = $filename;
          
        }
        
        
        $res = $data->update($input);
        if($res){
            return redirect()->back()->with('success','Office Bearer updated successfully');
        }
        else{
            if(file_exists(public_path('uploads/office-bearer/'.$filename))){
                unlink(public_path('uploads/office-bearer/'.$filename));
            }
            return redirect()->back()->with('error','Something went wrong');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)

    {
        $id = $request->id;
      $officebearer = OfficeBearer::find($id);
     
   if(($officebearer->image!=null) && (file_exists('uploads/office-bearer/'.$officebearer->image))){
    unlink('uploads/office-bearer/'.$officebearer->image);
     $res = $officebearer->delete();
            }
            if($res){
                return redirect()->back()->with('success','Office Bearer Record Deleted Successfully');
    
               }
               else{
                return redirect()->back()->with('error','Something Went Wrong unable to Delete Record');
               }
    
    }   
}