<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Presit;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class PresitDirectoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.presit.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.presit.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'presit_name' =>'required',
            'phone' =>'required',
            'presit_image'=>'required|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            'current_church' =>'nullable',
            'current_role' => 'nullable',
           
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        $input['name'] = $request->presit_name;

        $presit = new Presit();
        if($request->hasFile('presit_image')){
            $image = $request->file('presit_image');
            $filename = 'presit'.time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/presit');
            $image->move($path, $filename);
           $input['image'] = $filename;

            
        }
        // $res = $presit->create($input);
        $presit->name = $input['name'];
        $presit->phone =$input['phone'];
        $presit->current_role = $input['current_role'];
        $presit->current_chruch =$input['current_church'];
        $presit->image =$input['image'];
        $res = $presit->save();

        if($res){
            return redirect()->back()->with('success','Presit Added to Directory Successfully');

        }
        else{
            return redirect()->back()->with('error','Something went Wrong on Presit Insertion');
        }


    }

    public function get_presit(Request $request){
        if ($request->ajax()) {
            $data = Presit::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-presit', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
               
                ->addColumn('presit_image', function ($data) {
                   $image = $data->image;
                    if($image != null){
                        return  '<img src="' . asset('uploads/presit/' . $image) . '" width="100" height="100">';
                    }
                   
                    
                })
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])
    
                ->make(true);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data= Presit::find($id);
        return view('admin.pages.presit.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $input = $request->all();
        $data = Presit::find($id);
        if($request->hasFile('presit_image')){
            if(($data->image!=null) && file_exists('uploads/presit/'.$data->image)){
                unlink('uploads/presit/'.$data->image);
            }
            $image = $request->file('presit_image');
            $filename = 'presit'.time() . '.' . $image->getClientOriginalExtension();
            $path = public_path('uploads/presit');
            $image->move($path, $filename);
            $input['image'] = $filename;
            $data->image =$input['image'];
         
        }
        $data->name = $input['presit_name'];
        $data->phone =$input['phone'];
        $data->current_role = $input['current_role'];
        $data->current_chruch =$input['current_church'];
       
        $res = $data->save();
        if($res){
            return redirect()->back()->with('success','Presit Record Updated Successfully');
        }
        else{
            return redirect()->back()->with('error','Something Went Wrong Unable to Update Presit Record');
        }
    }
    public function changePresitStatus(Request $request){
        $res = Presit::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $presit  = Presit::find($request->id);
        
            if(($presit->image!=null) && (file_exists('uploads/presit/'.$presit->image))){
              unlink('uploads/presit/'.$presit->image);
               $res =$presit->delete();
                      }
           if($res){
            return redirect()->back()->with('success','Presit Record Deleted Successfully');

           }
           else{
            return redirect()->back()->with('error','Something Went Wrong unable to Delete Record');
           }
        
    }
}
