<?php

namespace App\Http\Controllers\Admin\Projects;

use App\Http\Controllers\Controller;
use App\Models\ProjectOverview;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class ProjectOverviewController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.projects.overview.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.projects.overview.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'project_name' => 'required|unique:project_overviews',
            'project_description' => 'required',
            'sub_heading' => 'required',
            'project_icon' => 'required|mimes:jpeg,jpg,png',


        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
      
        $input = $request->all();
        $input['sub_title'] =$request->sub_heading;
        if($request->hasFile('project_icon')){
            $file = $request->file('project_icon');
            $extension = $file->getClientOriginalExtension();
            $filename = 'projects-'.time() . '.' . $extension;
            $file->move('uploads/projects/icons/', $filename);
            $input['project_icon'] = $filename;
        }
    $project = ProjectOverview::create($input);
    if($project){
        return redirect()->back()->with('success', 'Project Added Successfully');
    }
    else {
        return redirect()->back()->with('error', 'Something went wrong');
    }

        
    }

    /**
     * Display the specified resource.
     */
    public function show(Request $request)
    {
        if ($request->ajax()) {
            $data = ProjectOverview::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.project-overview.edit', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
               
                ->addColumn('project_icon', function ($data) {
                     $image = $data->project_icon;
                    if($image != null){
                        return  '<img src="' . asset('uploads/projects/icons/' . $image) . '" width="100" height="100">';
                    }
                    return $image;
                    
                })
            
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
    }

    public function changeProjectOverviewStatus(Request $request){
        $res = ProjectOverview::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = ProjectOverview::find($id);
        return view('admin.pages.projects.overview.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $data = ProjectOverview::find($id);
       $validator = Validator::make($request->all(), [
           'project_name' => 'required',
           'project_description' => 'required',
           'sub_heading' => 'required',
           'project_icon' => 'nullable|mimes:jpeg,jpg,png',
       ]);
       if($validator->fails()){
           return redirect()->back()->withErrors($validator)->withInput();
       }
       $input = $request->all();
       $input['sub_title'] =$request->sub_heading;
       if($request->hasFile('project_icon')){
        if(file_exists(public_path('uploads/projects/icons' . $data->project_icon))) {
            unlink("uploads/projects/" . $data->project_icon);
        }
           $file = $request->file('project_icon');
           $extension = $file->getClientOriginalExtension();
           $filename = 'projects-'.time() . '.' . $extension;
           $file->move('uploads/projects/icons', $filename);
           $input['project_icon'] = $filename;
       }
       $project = $data->update($input);
       if($project){
           return redirect()->back()->with('success', 'Project Updated Successfully');
       }
       else {
           return redirect()->back()->with('error', 'Something went wrong');
       }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $id = $request->id;
        $data = ProjectOverview::find($id);
        if ((file_exists(public_path('uploads/projects/icons/' . $data->project_icon))) && ($data->project_icon != NULL)) {
            unlink("uploads/projects/icons/" . $data->project_icon);
            $res = $data->delete();
        }
     
        if($res){
            return redirect()->back()->with('sucess', 'Project deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong while deleting project');
        }
    }
}
