<?php

namespace App\Http\Controllers\Admin\Projects;

use App\Http\Controllers\Controller;
use App\Models\ProjectReport;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables;

class ProjectReportController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.projects.reports.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
      return view('admin.pages.projects.reports.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator =Validator::make($request->all(), [
            'report_name' => 'required',
            'report_description' => 'required',
            'report_pdf'=>'required|mimes:pdf',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
       
        if($request->hasFile('report_pdf')){
            $file = $request->file('report_pdf');
            $extension = $file->getClientOriginalExtension();
            $filename = 'reports-'.time() . '.' . $extension;
            $file->move('uploads/projects/reports/', $filename);
            $pdf= $filename;
        }


        $res = ProjectReport::create([
            'title' => $request->report_name,
            'description' => $request->report_description,
             'report'=>$pdf
        ]);
        if($res){
            return redirect()->back()->with('success', 'Report Added Successfully');
        }
        else{
            if(file_exists('uploads/projects/reports/'.$filename)){
                unlink('uploads/projects/reports/'.$filename);
            }
            return redirect()->back()->with('error', 'Something went wrong');
        }
         
    }

    /**
     * Display the specified resource.
     */
    public function show(Request $request)
    {
        if ($request->ajax()) {
            $data = ProjectReport::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.project-reports.edit', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
               
                ->addColumn('report_pdf', function ($data) {
                     $pdf = $data->report;
                    if($pdf != null){
                        return '<a href="' . asset('uploads/projects/reports/' . $data->report) . '" target="_blank" class="attachment-link">
            <img src="' . asset('assets/images/PDF_file_icon.png') . '" alt="pdf" width="50" height="50">
        </a>';
                    }
                    return $pdf;
                    
                })
            
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = ProjectReport::find($id);
       return view('admin.pages.projects.reports.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(), [
            'report_name' => 'required',
            'report_description' => 'required',
            'report_pdf'=>'nullable|mimes:pdf',
        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $data = ProjectReport::find($id);
        if($request->hasFile('report_pdf')){
            if(file_exists('uploads/projects/reports/'.$data->report)){
                unlink('uploads/projects/reports/'.$data->report);
            }
            $file = $request->file('report_pdf');
            $extension = $file->getClientOriginalExtension();
            $filename = 'reports-'.time() . '.' . $extension;
            $file->move('uploads/projects/reports/', $filename);
            $pdf= $filename;
            
        }else{
            $pdf = $data->report;
        }
        $res = $data->update([
            'title' => $request->report_name,
            'description' => $request->report_description,
            'report'=>$pdf
            
        ]);
        if($res){
            return redirect()->back()->with('success', 'Report Updated Successfully');
        }
        else{
            if(file_exists('uploads/projects/reports/'.$filename)){
                unlink('uploads/projects/reports/'.$filename);
            }
            return redirect()->back()->with('error', 'Something went wrong');
        }

    }

    public function  changeProjectReportStatus(Request $request){
        $res = ProjectReport::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request){
        $id = $request->id;
        $data = ProjectReport::find($id);
        if(file_exists('uploads/projects/reports/'.$data->report)){
            unlink('uploads/projects/reports/'.$data->report);
        }
        $res = $data->delete();
        if($res){
            return redirect()->back()->with('success', 'Report Deleted Successfully');
        }
        else{
            return redirect()->back()->with('error', 'Something went wrong');
        }
    }
}
