<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\SpiritualGallery;
use App\Models\SpiritualWings;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;

class SpiritualWingsController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.pages.spiritual-wings.list');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.pages.spiritual-wings.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator($request->all(), [
            'title' => 'required|string|min:3|max:255|unique:spiritual_wings,title',
            'heading' => 'required|string|min:10|max:255',
            'about' => 'required',
            'spiritual_image'=>'nullable|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            

        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        // $spiritualId = SpiritualWings::insertGetId([
        //     'title' => $input['title'],
        //     'sub-title' => $input['heading'],
        //     'about' => $input['about'],
        
        // ]);
        $input['sub_title'] = $request->heading;
        $spiritualWings = new SpiritualWings($input);
        $spiritualWings->save();
        $spiritualId = $spiritualWings->id;
        
        if ($spiritualId) {
            // Insert the News Images record using the obtained News ID
          
    
           
            if ($request->hasFile('spiritual_images')) {
                $images = $request->file('spiritual_images');
                foreach ($images as $spiritualimage) {
                   
                    // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                    $filename = 'spiritual-'.time().'.'.$spiritualimage->getClientOriginalExtension();
                    $path = public_path('uploads/spiritual-wings');
                    $spiritualimage->move($path, $filename);
            
                    // You can now save the $filename to your database or perform any other operations you need.
                    $spiritualgallery = new SpiritualGallery();
                $spiritualgallery->image = $filename;
                $spiritualgallery->spiritual_id = $spiritualId;
                $spiritualgallery->save();
                }
            }
            return redirect()->back()->with('success','Spiritual Wing created successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong');
        }

    }
    public function getspiritualwings(Request $request){
        if ($request->ajax()) {
            $data = SpiritualWings::orderBy('id', 'DESC')->get();
            return DataTables::of($data)
               ->addIndexColumn()
                ->addColumn('action', function ($data) {
                    $actionBtn = ' 
                    <a href="' . route('admin.edit-spiritual-wings', ['id' => $data->id]) . '" class="text-muted" title="send quotation"> <span class="badge badge-success"><i class="far fa-edit"></i></span></a>
                    
                    <a  href="javascript:void(0);" data-id="' . $data->id . '"  id="getDeleteId" class="text-muted"> <span class="badge badge-danger"><i class="far fa-trash-alt"></i></span></a>';
                    return $actionBtn;
                })
                
               
                ->addColumn('featured_image', function ($data) {
                     $image = $data->spiritualgallery->first();
                    if($image != null){
                        return  '<img src="' . asset('uploads/spiritual-wings/' . $image->image) . '" width="100" height="100">';
                    }
                    return $image;
                    
                })
                
                ->addColumn('status', function ($data) {
                    if ($data->status == 1) {
                        $status = 'Active';
                        $class = "success";
                        $val = 0;
                    } else {
                        $status = 'Inactive';
                        $class = "danger";
                        $val = 1;
                    }
                    return '<a href="javascript:void(0)" data-id="' . $data->id . '" data-value="' . $val . '" id="status"><span class="badge badge-' . $class . '">' . $status . '</span></a>';
                })
                ->escapeColumns([])

                ->make(true);
        }
    }


    public function changeSpiritualStatus(Request $request){
        $res = SpiritualWings::where('id', $request->id)
        ->update(['status' => $request->status]);

    return $res;
    }
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = SpiritualWings::find($id);
        return view('admin.pages.spiritual-wings.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator($request->all(), [
            'title' => 'required|string|min:3|max:255',
            'heading' => 'required|string|min:10|max:255',
            'about' => 'required',
            // 'spiritual_image'=>'nullable|image|mimes:jpeg,png,jpg,gif,svg,avif,webp|max:2048',
            

        ]);
        if($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $input = $request->all();
        $input['sub-_title'] = $request->heading;
        $spiritualWings = SpiritualWings::find($id);
        $res =  $spiritualWings->update($input); 
        if ($request->hasFile('spiritual_images')) {
            $images = $request->file('spiritual_images');
            foreach ($images as $spiritualimage) {
              
                // $filename = time() . '_' . $newsimage->getClientOriginalName(); // Use the original file name
                $filename = 'spiritual-'.time().'.'.$spiritualimage->getClientOriginalName();
                $path = public_path('uploads/spiritual-wings');
                $spiritualimage->move($path, $filename);
        
                // You can now save the $filename to your database or perform any other operations you need.
                $spiritualgallery = new SpiritualGallery(); // You should create an instance of the NewsGallery model or use your own model name
                $spiritualgallery->image = $filename;
                $spiritualgallery->spiritual_id = $id;
                $spiritualgallery->save();
            }
        }
        if($res){
            return redirect()->back()->with('success','Spiritual Wing updated successfully');
        }
        else{
            return redirect()->back()->with('error','Something Went Wrong');
        }
        
    }





    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        $spiritualWings = SpiritualWings::find($request->id);


    }



    public function editspiritualgallery  (Request $request,string $id){
        $data= SpiritualGallery::find($id);
        return view('admin.pages.spiritual-wings.editspiritualgallery',compact('data'));
        
    }
    public function destroyspiritualgallery (string $id){
        $data= SpiritualGallery::find($id);
        if($data){
            if((file_exists(public_path('uploads/spiritual-wings/' . $data->image))) && ($data->image != NULL)) {
                unlink("uploads/spiritual-wings/" . $data->image);
            }
            $data->delete();
            return redirect()->back()->with('success','Spiritual gallery image deleted successfully');
        }
        else{
            return redirect()->back()->with('error','Something went wrong');
        }
    }
    public function updatespiritualgallery(Request $request,string $id){
        $data= SpiritualGallery::find($id);
        if ($data) {
            if ($request->hasFile('image')) {
                $newsimage = $request->file('image');
                if ((file_exists(public_path('uploads/spiritual-wings/' . $data->image))) && ($data->image != NULL)) {
                    unlink("uploads/spiritual-wings/" . $data->image);
                }
                $filename = 'spiritual-' . time() . '.' . $newsimage->getClientOriginalExtension();
                $path = public_path('uploads/spiritual-wings');
                $newsimage->move($path, $filename);
                $data->image = $filename;
                $id = $data->spiritual_id;
                $data->save();
                
                
                return redirect()->route('admin.edit-spiritual-wings',['id' => $id])->with('success','Spiritual gallery image updated successfully');

                
            }
    }


}
}
